@@ -1,5 +1,7 @@
 import os
 
+import shutil
+
 from appdirs import user_cache_dir
 
 from .locked_shelf import LockedShelf
@@ -27,7 +29,7 @@ class CachedFunction:
         return value
 
 
-def permacache(path, key_function=lambda *args, **kwargs: [args, kwargs]):
+def permacache(path, key_function=dict()):
     path = os.path.join(CACHE, path)
 
     def annotator(f):
@@ -37,3 +39,15 @@ def permacache(path, key_function=lambda *args, **kwargs: [args, kwargs]):
         return CachedFunction(f, kf, path)
 
     return annotator
+
+
+def to_file(path, zip_path):
+    path = os.path.join(CACHE, path)
+    shutil.make_archive(zip_path, "zip", path)
+
+
+def from_file(path, zip_path):
+    path = os.path.join(CACHE, path)
+    if os.path.exists(path):
+        raise RuntimeError(f"Cache already exists: {path}")
+    shutil.unpack_archive(zip_path + ".zip", path, "zip")
